{
    "$graph": [
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx50g",
                "-Djava.io.tmpdir=$(runtime.tmpdir)",
                "-jar",
                "$(inputs.abra)",
                {
                    "prefix": "--tmpdir",
                    "valueFrom": "$(runtime.tmpdir)"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": "$(inputs.ram_min)",
                    "coresMin": "$(inputs.cores_min)",
                    "outdirMax": 120000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#abra.cwl/abra"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ca"
                    },
                    "id": "#abra.cwl/ca"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--cons"
                    },
                    "id": "#abra.cwl/cons"
                },
                {
                    "type": "int",
                    "id": "#abra.cwl/cores_min"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--index"
                    },
                    "id": "#abra.cwl/index"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "--in",
                        "itemSeparator": ","
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#abra.cwl/input_bams"
                },
                {
                    "type": "string",
                    "id": "#abra.cwl/java"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--kmer"
                    },
                    "id": "#abra.cwl/kmer"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--mad"
                    },
                    "id": "#abra.cwl/mad"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--mmr"
                    },
                    "id": "#abra.cwl/mmr"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--out"
                    },
                    "id": "#abra.cwl/out"
                },
                {
                    "type": "string",
                    "id": "#abra.cwl/patient_id"
                },
                {
                    "type": "int",
                    "id": "#abra.cwl/ram_min"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#abra.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sc"
                    },
                    "id": "#abra.cwl/sc"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sga"
                    },
                    "id": "#abra.cwl/sga"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--targets"
                    },
                    "id": "#abra.cwl/targets"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--threads"
                    },
                    "id": "#abra.cwl/threads"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ws"
                    },
                    "id": "#abra.cwl/ws"
                }
            ],
            "id": "#abra.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_IR.bam",
                        "outputEval": "${\n  var sorted_output_bams = [];\n\n  inputs.out.forEach(function(output_bam_filename) {\n    self.forEach(function(realigned_bam) {\n      if (output_bam_filename === realigned_bam.basename) {\n\n        sorted_output_bams.push(realigned_bam);\n\n      }\n    });\n  });\n\n  return sorted_output_bams\n}\n"
                    },
                    "id": "#abra.cwl/bams"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx30g",
                "-jar",
                "$(inputs.gatk)",
                "-T",
                "BaseRecalibrator"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 40000,
                    "coresMin": 8,
                    "outdirMax": 100000,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": "string",
                    "id": "#BaseQualityScoreRecalibration.cwl/gatk"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#BaseQualityScoreRecalibration.cwl/input_bam"
                },
                {
                    "type": "string",
                    "id": "#BaseQualityScoreRecalibration.cwl/java"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-knownSites"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/known_sites_1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-knownSites"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/known_sites_2"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-nct"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/nct"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The output recalibration table file to create",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/out"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-rf"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/rf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.out)\n    return inputs.out;\n  return null;\n}\n"
                    },
                    "id": "#BaseQualityScoreRecalibration.cwl/recal_matrix"
                }
            ],
            "id": "#BaseQualityScoreRecalibration.cwl"
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx20g",
                "-jar",
                "$(inputs.gatk)",
                "-T",
                "FindCoveredIntervals"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 25000,
                    "coresMin": 2,
                    "outdirMax": 110000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--input_file",
                            "position": 100
                        }
                    },
                    "id": "#FindCoveredIntervals.cwl/bams"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--coverage_threshold",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/coverage_threshold"
                },
                {
                    "type": "string",
                    "id": "#FindCoveredIntervals.cwl/gatk"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--allow_potentially_misencoded_quality_scores",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/ignore_misencoded_base_qualities"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "--intervals",
                                "position": 100
                            }
                        }
                    ],
                    "id": "#FindCoveredIntervals.cwl/intervals"
                },
                {
                    "type": "string",
                    "id": "#FindCoveredIntervals.cwl/java"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minBaseQuality",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/min_base_quality"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minMappingQuality",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--out",
                        "position": 100
                    },
                    "id": "#FindCoveredIntervals.cwl/out"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--read_filter",
                            "position": 100
                        }
                    },
                    "id": "#FindCoveredIntervals.cwl/read_filters"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference_sequence"
                    },
                    "id": "#FindCoveredIntervals.cwl/reference_sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out)"
                    },
                    "id": "#FindCoveredIntervals.cwl/fci_list"
                }
            ],
            "id": "#FindCoveredIntervals.cwl"
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx4g",
                "-jar",
                "$(inputs.gatk)",
                "-T",
                "PrintReads"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 10000,
                    "coresMin": 8,
                    "outdirMax": 50000,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "doc": "Input covariates table file for on-the-fly base quality score recalibration",
                    "inputBinding": {
                        "prefix": "--BQSR"
                    },
                    "id": "#PrintReads.cwl/BQSR"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-EOQ"
                    },
                    "id": "#PrintReads.cwl/EOQ"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Type of BAQ calculation to apply in the engine (OFF| CALCULATE_AS_NECESSARY| RECALCULATE)",
                    "inputBinding": {
                        "prefix": "--baq"
                    },
                    "id": "#PrintReads.cwl/baq"
                },
                {
                    "type": "string",
                    "id": "#PrintReads.cwl/gatk"
                },
                {
                    "type": "File",
                    "doc": "Input file containing sequence data (SAM or BAM)",
                    "inputBinding": {
                        "prefix": "--input_file"
                    },
                    "id": "#PrintReads.cwl/input_file"
                },
                {
                    "type": "string",
                    "id": "#PrintReads.cwl/java"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-nct"
                    },
                    "id": "#PrintReads.cwl/nct"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Write output to this BAM filename instead of STDOUT",
                    "inputBinding": {
                        "prefix": "--out"
                    },
                    "id": "#PrintReads.cwl/out"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--reference_sequence"
                    },
                    "id": "#PrintReads.cwl/reference_sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if (inputs.out)\n    return inputs.out;\n  return null;\n}\n"
                    },
                    "id": "#PrintReads.cwl/out_bams"
                }
            ],
            "id": "#PrintReads.cwl"
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "$(inputs.java)",
                "-Xmx24g",
                "-jar",
                "$(inputs.fix_mate_information)",
                "TMP_DIR=/scratch"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 30000,
                    "coresMin": 5,
                    "outdirMax": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "doc": "None\n",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "COMPRESSION_LEVEL=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/compression_level"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "CREATE_INDEX=true"
                    },
                    "id": "#FixMateInformation.cwl/create_index"
                },
                {
                    "type": "string",
                    "id": "#FixMateInformation.cwl/fix_mate_information"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/input_bam"
                },
                {
                    "type": "string",
                    "id": "#FixMateInformation.cwl/java"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))",
                    "inputBinding": {
                        "prefix": "O=",
                        "separate": false,
                        "valueFrom": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))"
                    },
                    "id": "#FixMateInformation.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "SO=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "TMP_DIR=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/tmp_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "VALIDATION_STRINGENCY=",
                        "separate": false
                    },
                    "id": "#FixMateInformation.cwl/validation_stringency"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.basename.replace('.bam', '_FX.bai'))"
                    },
                    "id": "#FixMateInformation.cwl/bai"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.basename.replace('.bam', '_FX.bam'))"
                    },
                    "id": "#FixMateInformation.cwl/bam"
                }
            ],
            "id": "#FixMateInformation.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "list2bed"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 5000,
                    "coresMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--input_file"
                    },
                    "id": "#list2bed.cwl/input_file"
                },
                {
                    "type": "string",
                    "doc": "Name for the output bed file",
                    "inputBinding": {
                        "prefix": "--output_file"
                    },
                    "id": "#list2bed.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "doc": "Whether to sort bed file output",
                    "inputBinding": {
                        "prefix": "--sort"
                    },
                    "id": "#list2bed.cwl/sort"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${return inputs.output_filename}"
                    },
                    "id": "#list2bed.cwl/output_file"
                }
            ],
            "id": "#list2bed.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#collapsing_tools.yaml/run_tools",
                            "fields": [
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/perl_5",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/java_7",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/java_8",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/marianas_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/bioinfo_utils",
                                    "type": "File"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/trimgalore_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/bwa_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/arrg_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/picard_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/gatk_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/abra_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/fx_path",
                                    "type": "string"
                                },
                                {
                                    "name": "#collapsing_tools.yaml/run_tools/waltz_path",
                                    "type": "string"
                                }
                            ]
                        },
                        {
                            "name": "#find_covered_intervals.yaml/find_covered_intervals__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/minbq",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/minmq",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/cov",
                                    "type": "int"
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/rf",
                                    "type": {
                                        "type": "array",
                                        "items": "string"
                                    }
                                },
                                {
                                    "name": "#find_covered_intervals.yaml/find_covered_intervals__params/intervals",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "string"
                                        }
                                    ]
                                }
                            ]
                        },
                        {
                            "name": "#abra.yaml/abra__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#abra.yaml/abra__params/ram_min",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/cores_min",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/threads",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/kmers",
                                    "type": [
                                        "null",
                                        "string"
                                    ]
                                },
                                {
                                    "name": "#abra.yaml/abra__params/mad",
                                    "type": "int"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/sc",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/mmr",
                                    "type": "float"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/sga",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/ca",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/ws",
                                    "type": "string"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/index",
                                    "type": "boolean"
                                },
                                {
                                    "name": "#abra.yaml/abra__params/cons",
                                    "type": "boolean"
                                }
                            ]
                        },
                        {
                            "name": "#fix_mate_information.yaml/fix_mate_information__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/sort_order",
                                    "type": "string"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/validation_stringency",
                                    "type": "string"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/compression_level",
                                    "type": "int"
                                },
                                {
                                    "name": "#fix_mate_information.yaml/fix_mate_information__params/create_index",
                                    "type": "boolean"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "#abra.yaml/abra__params",
                    "id": "#abra_workflow.cwl/abra__params"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#abra_workflow.cwl/bams"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#abra_workflow.cwl/fci__basq_fix"
                },
                {
                    "type": "#find_covered_intervals.yaml/find_covered_intervals__params",
                    "id": "#abra_workflow.cwl/find_covered_intervals__params"
                },
                {
                    "type": "#fix_mate_information.yaml/fix_mate_information__params",
                    "id": "#abra_workflow.cwl/fix_mate_information__params"
                },
                {
                    "type": "string",
                    "id": "#abra_workflow.cwl/patient_id"
                },
                {
                    "type": "string",
                    "id": "#abra_workflow.cwl/reference_fasta"
                },
                {
                    "type": "#collapsing_tools.yaml/run_tools",
                    "id": "#abra_workflow.cwl/run_tools"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#abra_workflow.cwl/list2bed/output_file",
                    "id": "#abra_workflow.cwl/covint_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#abra_workflow.cwl/find_covered_intervals/fci_list",
                    "id": "#abra_workflow.cwl/covint_list"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#abra_workflow.cwl/parallel_fixmate/bams",
                    "id": "#abra_workflow.cwl/ir_bams"
                }
            ],
            "steps": [
                {
                    "run": "#abra.cwl",
                    "in": [
                        {
                            "valueFrom": "$(inputs.run_tools.abra_path)",
                            "id": "#abra_workflow.cwl/abra/abra"
                        },
                        {
                            "valueFrom": "$(inputs.params.ca)",
                            "id": "#abra_workflow.cwl/abra/ca"
                        },
                        {
                            "valueFrom": "$(inputs.params.cons)",
                            "id": "#abra_workflow.cwl/abra/cons"
                        },
                        {
                            "valueFrom": "$(inputs.params.cores_min)",
                            "id": "#abra_workflow.cwl/abra/cores_min"
                        },
                        {
                            "valueFrom": "$(inputs.params.index)",
                            "id": "#abra_workflow.cwl/abra/index"
                        },
                        {
                            "source": "#abra_workflow.cwl/bams",
                            "id": "#abra_workflow.cwl/abra/input_bams"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_8)",
                            "id": "#abra_workflow.cwl/abra/java"
                        },
                        {
                            "valueFrom": "$(inputs.params.mad)",
                            "id": "#abra_workflow.cwl/abra/mad"
                        },
                        {
                            "valueFrom": "$(inputs.params.mmr)",
                            "id": "#abra_workflow.cwl/abra/mmr"
                        },
                        {
                            "valueFrom": "$(inputs.input_bams.map(function(b){return b.basename.replace('.bam', '_IR.bam')}))",
                            "id": "#abra_workflow.cwl/abra/out"
                        },
                        {
                            "source": "#abra_workflow.cwl/abra__params",
                            "id": "#abra_workflow.cwl/abra/params"
                        },
                        {
                            "source": "#abra_workflow.cwl/patient_id",
                            "id": "#abra_workflow.cwl/abra/patient_id"
                        },
                        {
                            "valueFrom": "$(inputs.params.ram_min)",
                            "id": "#abra_workflow.cwl/abra/ram_min"
                        },
                        {
                            "source": "#abra_workflow.cwl/reference_fasta",
                            "id": "#abra_workflow.cwl/abra/reference_fasta"
                        },
                        {
                            "source": "#abra_workflow.cwl/run_tools",
                            "id": "#abra_workflow.cwl/abra/run_tools"
                        },
                        {
                            "valueFrom": "$(inputs.params.sc)",
                            "id": "#abra_workflow.cwl/abra/sc"
                        },
                        {
                            "valueFrom": "$(inputs.params.sga)",
                            "id": "#abra_workflow.cwl/abra/sga"
                        },
                        {
                            "source": "#abra_workflow.cwl/list2bed/output_file",
                            "id": "#abra_workflow.cwl/abra/targets"
                        },
                        {
                            "valueFrom": "$(inputs.params.threads)",
                            "id": "#abra_workflow.cwl/abra/threads"
                        },
                        {
                            "valueFrom": "$(inputs.params.ws)",
                            "id": "#abra_workflow.cwl/abra/ws"
                        }
                    ],
                    "out": [
                        "#abra_workflow.cwl/abra/bams"
                    ],
                    "id": "#abra_workflow.cwl/abra"
                },
                {
                    "run": "#FindCoveredIntervals.cwl",
                    "in": [
                        {
                            "source": "#abra_workflow.cwl/bams",
                            "id": "#abra_workflow.cwl/find_covered_intervals/bams"
                        },
                        {
                            "valueFrom": "$(inputs.params.cov)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/coverage_threshold"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.gatk_path)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/gatk"
                        },
                        {
                            "source": "#abra_workflow.cwl/fci__basq_fix",
                            "id": "#abra_workflow.cwl/find_covered_intervals/ignore_misencoded_base_qualities"
                        },
                        {
                            "valueFrom": "${\n  return inputs.params.intervals ? inputs.params.intervals : null\n}\n",
                            "id": "#abra_workflow.cwl/find_covered_intervals/intervals"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_7)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/java"
                        },
                        {
                            "valueFrom": "$(inputs.params.minbq)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/min_base_quality"
                        },
                        {
                            "valueFrom": "$(inputs.params.minmq)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/min_mapping_quality"
                        },
                        {
                            "valueFrom": "${return inputs.patient_id + '.fci.list'}",
                            "id": "#abra_workflow.cwl/find_covered_intervals/out"
                        },
                        {
                            "source": "#abra_workflow.cwl/find_covered_intervals__params",
                            "id": "#abra_workflow.cwl/find_covered_intervals/params"
                        },
                        {
                            "source": "#abra_workflow.cwl/patient_id",
                            "id": "#abra_workflow.cwl/find_covered_intervals/patient_id"
                        },
                        {
                            "valueFrom": "$(inputs.params.rf)",
                            "id": "#abra_workflow.cwl/find_covered_intervals/read_filters"
                        },
                        {
                            "source": "#abra_workflow.cwl/reference_fasta",
                            "id": "#abra_workflow.cwl/find_covered_intervals/reference_sequence"
                        },
                        {
                            "source": "#abra_workflow.cwl/run_tools",
                            "id": "#abra_workflow.cwl/find_covered_intervals/run_tools"
                        }
                    ],
                    "out": [
                        "#abra_workflow.cwl/find_covered_intervals/fci_list"
                    ],
                    "id": "#abra_workflow.cwl/find_covered_intervals"
                },
                {
                    "run": "#list2bed.cwl",
                    "in": [
                        {
                            "source": "#abra_workflow.cwl/find_covered_intervals/fci_list",
                            "id": "#abra_workflow.cwl/list2bed/input_file"
                        },
                        {
                            "valueFrom": "${return inputs.input_file.basename.replace('.list', '.bed.srt')}",
                            "id": "#abra_workflow.cwl/list2bed/output_filename"
                        }
                    ],
                    "out": [
                        "#abra_workflow.cwl/list2bed/output_file"
                    ],
                    "id": "#abra_workflow.cwl/list2bed"
                },
                {
                    "in": [
                        {
                            "source": "#abra_workflow.cwl/abra/bams",
                            "id": "#abra_workflow.cwl/parallel_fixmate/bam"
                        },
                        {
                            "valueFrom": "$(inputs.params.compression_level)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/compression_level"
                        },
                        {
                            "valueFrom": "$(inputs.params.create_index)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/create_index"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.fx_path)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/fix_mate_information"
                        },
                        {
                            "valueFrom": "$(inputs.run_tools.java_7)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/java"
                        },
                        {
                            "source": "#abra_workflow.cwl/fix_mate_information__params",
                            "id": "#abra_workflow.cwl/parallel_fixmate/params"
                        },
                        {
                            "source": "#abra_workflow.cwl/run_tools",
                            "id": "#abra_workflow.cwl/parallel_fixmate/run_tools"
                        },
                        {
                            "valueFrom": "$(inputs.params.sort_order)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/sort_order"
                        },
                        {
                            "valueFrom": "$(inputs.params.validation_stringency)",
                            "id": "#abra_workflow.cwl/parallel_fixmate/validation_stringency"
                        }
                    ],
                    "out": [
                        "#abra_workflow.cwl/parallel_fixmate/bams"
                    ],
                    "scatter": [
                        "#abra_workflow.cwl/parallel_fixmate/bam"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": {
                        "class": "Workflow",
                        "inputs": [
                            {
                                "type": "File",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/bam"
                            },
                            {
                                "type": "int",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/compression_level"
                            },
                            {
                                "type": "boolean",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/create_index"
                            },
                            {
                                "type": "string",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/fix_mate_information"
                            },
                            {
                                "type": "string",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/java"
                            },
                            {
                                "type": "string",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/sort_order"
                            },
                            {
                                "type": "string",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/validation_stringency"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputSource": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/bam",
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/bams"
                            }
                        ],
                        "steps": [
                            {
                                "run": "#FixMateInformation.cwl",
                                "in": [
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/compression_level",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/compression_level"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/create_index",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/create_index"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/fix_mate_information",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/fix_mate_information"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/bam",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/input_bam"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/java",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/java"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/sort_order",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/sort_order"
                                    },
                                    {
                                        "source": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/validation_stringency",
                                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/validation_stringency"
                                    }
                                ],
                                "out": [
                                    "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information/bam"
                                ],
                                "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf/picard_fixmate_information"
                            }
                        ],
                        "id": "#abra_workflow.cwl/parallel_fixmate/fa1b1db5-38eb-4884-8d6d-2239982fdbcf"
                    },
                    "id": "#abra_workflow.cwl/parallel_fixmate"
                }
            ],
            "id": "#abra_workflow.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#collapsing_tools.yaml/run_tools"
                        },
                        {
                            "name": "#print_reads.yaml/print_reads__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#print_reads.yaml/print_reads__params/nct",
                                    "type": "int"
                                },
                                {
                                    "name": "#print_reads.yaml/print_reads__params/EOQ",
                                    "type": "boolean"
                                },
                                {
                                    "name": "#print_reads.yaml/print_reads__params/baq",
                                    "type": "string"
                                }
                            ]
                        },
                        {
                            "name": "#base_recalibrator.yaml/base_recalibrator__params",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#base_recalibrator.yaml/base_recalibrator__params/nct",
                                    "type": "int"
                                },
                                {
                                    "name": "#base_recalibrator.yaml/base_recalibrator__params/rf",
                                    "type": "string"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#bqsr_workflow.cwl/bams"
                },
                {
                    "type": "#base_recalibrator.yaml/base_recalibrator__params",
                    "id": "#bqsr_workflow.cwl/base_recalibrator__params"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#bqsr_workflow.cwl/bqsr__knownSites_dbSNP"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#bqsr_workflow.cwl/bqsr__knownSites_millis"
                },
                {
                    "type": "#print_reads.yaml/print_reads__params",
                    "id": "#bqsr_workflow.cwl/print_reads__params"
                },
                {
                    "type": "string",
                    "id": "#bqsr_workflow.cwl/reference_fasta"
                },
                {
                    "type": "#collapsing_tools.yaml/run_tools",
                    "id": "#bqsr_workflow.cwl/run_tools"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#bqsr_workflow.cwl/parallel_printreads/bams",
                    "id": "#bqsr_workflow.cwl/bqsr_bams"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#bqsr_workflow.cwl/parallel_bqsr/recal_matrix",
                    "id": "#bqsr_workflow.cwl/recalibrated_scores_matrix"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#bqsr_workflow.cwl/bams",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/bam"
                        },
                        {
                            "valueFrom": "${return inputs.run_tools.gatk_path}",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/gatk"
                        },
                        {
                            "valueFrom": "${return inputs.run_tools.java_7}",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/java"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/bqsr__knownSites_dbSNP",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/known_sites_1"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/bqsr__knownSites_millis",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/known_sites_2"
                        },
                        {
                            "valueFrom": "$(inputs.params.nct)",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/nct"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/base_recalibrator__params",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/params"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/reference_fasta",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/reference_fasta"
                        },
                        {
                            "valueFrom": "$(inputs.params.rf)",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/rf"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/run_tools",
                            "id": "#bqsr_workflow.cwl/parallel_bqsr/run_tools"
                        }
                    ],
                    "out": [
                        "#bqsr_workflow.cwl/parallel_bqsr/recal_matrix"
                    ],
                    "scatter": "#bqsr_workflow.cwl/parallel_bqsr/bam",
                    "scatterMethod": "dotproduct",
                    "run": {
                        "class": "Workflow",
                        "inputs": [
                            {
                                "type": "File",
                                "secondaryFiles": [
                                    "^.bai"
                                ],
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bam"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/gatk"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/java"
                            },
                            {
                                "type": "File",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/known_sites_1"
                            },
                            {
                                "type": "File",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/known_sites_2"
                            },
                            {
                                "type": "int",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/nct"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/reference_fasta"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/rf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputSource": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/recal_matrix",
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/recal_matrix"
                            }
                        ],
                        "steps": [
                            {
                                "run": "#BaseQualityScoreRecalibration.cwl",
                                "in": [
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/gatk",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/gatk"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bam",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/input_bam"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/java",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/java"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/known_sites_1",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/known_sites_1"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/known_sites_2",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/known_sites_2"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/nct",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/nct"
                                    },
                                    {
                                        "valueFrom": "$(inputs.input_bam.basename.replace('.bam', '.recal_matrix'))",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/out"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/reference_fasta",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/reference_fasta"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/rf",
                                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/rf"
                                    }
                                ],
                                "out": [
                                    "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr/recal_matrix"
                                ],
                                "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c/bqsr"
                            }
                        ],
                        "id": "#bqsr_workflow.cwl/parallel_bqsr/0141ee3c-2998-4c33-b104-af9c34314e3c"
                    },
                    "id": "#bqsr_workflow.cwl/parallel_bqsr"
                },
                {
                    "in": [
                        {
                            "source": "#bqsr_workflow.cwl/parallel_bqsr/recal_matrix",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/BQSR"
                        },
                        {
                            "valueFrom": "$(inputs.params.EOQ)",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/EOQ"
                        },
                        {
                            "valueFrom": "$(inputs.params.baq)",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/baq"
                        },
                        {
                            "valueFrom": "${return inputs.run_tools.gatk_path}",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/gatk"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/bams",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/input_file"
                        },
                        {
                            "valueFrom": "${return inputs.run_tools.java_7}",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/java"
                        },
                        {
                            "valueFrom": "$(inputs.params.nct)",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/nct"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/print_reads__params",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/params"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/reference_fasta",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/reference_sequence"
                        },
                        {
                            "source": "#bqsr_workflow.cwl/run_tools",
                            "id": "#bqsr_workflow.cwl/parallel_printreads/run_tools"
                        }
                    ],
                    "out": [
                        "#bqsr_workflow.cwl/parallel_printreads/bams"
                    ],
                    "scatter": [
                        "#bqsr_workflow.cwl/parallel_printreads/input_file",
                        "#bqsr_workflow.cwl/parallel_printreads/BQSR"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": {
                        "class": "Workflow",
                        "inputs": [
                            {
                                "type": "File",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/BQSR"
                            },
                            {
                                "type": "boolean",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/EOQ"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/baq"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk"
                            },
                            {
                                "type": "File",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/input_file"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/java"
                            },
                            {
                                "type": "int",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/nct"
                            },
                            {
                                "type": "string",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/reference_sequence"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "secondaryFiles": [
                                    "^.bai"
                                ],
                                "outputSource": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/out_bams",
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/bams"
                            }
                        ],
                        "steps": [
                            {
                                "run": "#PrintReads.cwl",
                                "in": [
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/BQSR",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/BQSR"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/EOQ",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/EOQ"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/baq",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/baq"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/gatk"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/input_file",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/input_file"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/java",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/java"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/nct",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/nct"
                                    },
                                    {
                                        "valueFrom": "${return inputs.input_file.basename.replace(\".bam\", \"_BR.bam\")}",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/out"
                                    },
                                    {
                                        "source": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/reference_sequence",
                                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/reference_sequence"
                                    }
                                ],
                                "out": [
                                    "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads/out_bams"
                                ],
                                "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c/gatk_print_reads"
                            }
                        ],
                        "id": "#bqsr_workflow.cwl/parallel_printreads/51bacc8b-8a86-4bf5-af56-d1c77ef15a5c"
                    },
                    "id": "#bqsr_workflow.cwl/parallel_printreads"
                }
            ],
            "id": "#bqsr_workflow.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#collapsing_tools.yaml/run_tools"
                        },
                        {
                            "$import": "#abra.yaml/abra__params"
                        },
                        {
                            "$import": "#print_reads.yaml/print_reads__params"
                        },
                        {
                            "$import": "#base_recalibrator.yaml/base_recalibrator__params"
                        },
                        {
                            "$import": "#fix_mate_information.yaml/fix_mate_information__params"
                        },
                        {
                            "$import": "#find_covered_intervals.yaml/find_covered_intervals__params"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "#abra.yaml/abra__params",
                    "id": "#main/abra__params"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bams"
                },
                {
                    "type": "#base_recalibrator.yaml/base_recalibrator__params",
                    "id": "#main/base_recalibrator__params"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/bqsr__knownSites_dbSNP"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/bqsr__knownSites_millis"
                },
                {
                    "type": "#find_covered_intervals.yaml/find_covered_intervals__params",
                    "id": "#main/find_covered_intervals__params"
                },
                {
                    "type": "#fix_mate_information.yaml/fix_mate_information__params",
                    "id": "#main/fix_mate_information__params"
                },
                {
                    "type": "string",
                    "id": "#main/patient_id"
                },
                {
                    "type": "#print_reads.yaml/print_reads__params",
                    "id": "#main/print_reads__params"
                },
                {
                    "type": "string",
                    "id": "#main/reference_fasta"
                },
                {
                    "type": "#collapsing_tools.yaml/run_tools",
                    "id": "#main/run_tools"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/ABRA_workflow/covint_bed",
                    "id": "#main/covint_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/ABRA_workflow/covint_list",
                    "id": "#main/covint_list"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/BQSR_workflow/recalibrated_scores_matrix",
                    "id": "#main/recalibrated_scores_matrix"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#main/BQSR_workflow/bqsr_bams",
                    "id": "#main/standard_bams"
                }
            ],
            "steps": [
                {
                    "run": "#abra_workflow.cwl",
                    "in": [
                        {
                            "source": "#main/abra__params",
                            "id": "#main/ABRA_workflow/abra__params"
                        },
                        {
                            "source": "#main/bams",
                            "id": "#main/ABRA_workflow/bams"
                        },
                        {
                            "valueFrom": "$(false)",
                            "id": "#main/ABRA_workflow/fci__basq_fix"
                        },
                        {
                            "source": "#main/find_covered_intervals__params",
                            "id": "#main/ABRA_workflow/find_covered_intervals__params"
                        },
                        {
                            "source": "#main/fix_mate_information__params",
                            "id": "#main/ABRA_workflow/fix_mate_information__params"
                        },
                        {
                            "source": "#main/patient_id",
                            "id": "#main/ABRA_workflow/patient_id"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/ABRA_workflow/reference_fasta"
                        },
                        {
                            "source": "#main/run_tools",
                            "id": "#main/ABRA_workflow/run_tools"
                        }
                    ],
                    "out": [
                        "#main/ABRA_workflow/ir_bams",
                        "#main/ABRA_workflow/covint_list",
                        "#main/ABRA_workflow/covint_bed"
                    ],
                    "id": "#main/ABRA_workflow"
                },
                {
                    "run": "#bqsr_workflow.cwl",
                    "in": [
                        {
                            "source": "#main/ABRA_workflow/ir_bams",
                            "id": "#main/BQSR_workflow/bams"
                        },
                        {
                            "source": "#main/base_recalibrator__params",
                            "id": "#main/BQSR_workflow/base_recalibrator__params"
                        },
                        {
                            "source": "#main/bqsr__knownSites_dbSNP",
                            "id": "#main/BQSR_workflow/bqsr__knownSites_dbSNP"
                        },
                        {
                            "source": "#main/bqsr__knownSites_millis",
                            "id": "#main/BQSR_workflow/bqsr__knownSites_millis"
                        },
                        {
                            "source": "#main/print_reads__params",
                            "id": "#main/BQSR_workflow/print_reads__params"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/BQSR_workflow/reference_fasta"
                        },
                        {
                            "source": "#main/run_tools",
                            "id": "#main/BQSR_workflow/run_tools"
                        }
                    ],
                    "out": [
                        "#main/BQSR_workflow/bqsr_bams",
                        "#main/BQSR_workflow/recalibrated_scores_matrix"
                    ],
                    "id": "#main/BQSR_workflow"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
